<?php
define("FAILED_TO_GET_TOKEN", 1);
define("INVALID_DIR_PATH", 2);
define("PERMISSION_ISSUES", 3);
define("UPLOAD_FAILED", 4);
define("SUCCESS", 0);

define("DS", "/");

class LogUpload
{
    private $dataDirectoryPath = "/var/www/html/data";
    private $uploadUrl = "https://platform.abuzzsolutions.asia/services/analytics/api/log-entries/upload";
    private $authUrl = "https://platform.abuzzsolutions.asia/auth/login";
    private $cmsK = "dGVjaDpBYnV6ekAxMjM=";
    private $token = "";

    public function __construct() {
        $this->token = $this->getAccessToken();
    }

    public function zipAndUploadCSVFiles() {
        $dir = $this->dataDirectoryPath;

        if(!is_dir($dir)) {
            $this->quite(INVALID_DIR_PATH);
        }

        $zip = new ZipArchive();

        $ffs = scandir($dir);

        foreach($ffs as $ff) {
            if($ff != '.' && $ff != '..') {

                $csvFile = $dir.DS.$ff;

                if(!is_dir($csvFile) && strpos($csvFile, '.csv') !== false) {
                    echo "<br> Processing file: ".$ff;

                    $zipFile = str_replace("csv", "zip", $csvFile);
                    if(file_exists($zipFile)) {
                        unlink($zipFile);
                    }

                    if($zip->open($zipFile, ZIPARCHIVE::CREATE) !== true) {
                        $this->quite(PERMISSION_ISSUES);
                    }
                    $zip->addFile($csvFile, $ff);
                    $zip->close();

                    $siteCode = str_replace(["stats-", "-MOBILE.csv"], "", $ff);
                    $playerCode = $siteCode."-MOBILE";

                    if($this->uploadLogFile($siteCode, $playerCode, $zipFile) == true) {
                        echo "<br> Done.";
                    } else {
                        echo "<br>ERROR uploading.";
                    }
                }
            }
        }
    }

    private function uploadLogFile($siteCode, $playerCode, $fileFullPath) {

        if (function_exists('curl_file_create')) {

            $cFile = curl_file_create($fileFullPath, "application/zip", basename($fileFullPath));

        } else {
            $cFile = '@' . realpath($fileFullPath);
        }

        $post = array('file' => $cFile);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $this->uploadUrl);
        curl_setopt($ch, CURLOPT_POST, 1);
        //curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Authorization: ' . $this->token,
            'siteCode: ' . $siteCode,
            'groupCode: ' . $playerCode . '-GRP',
            'playerCode: ' . $playerCode,
        ));
        curl_exec($ch);
        $status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close ($ch);

        if($status === 200) {
            return true;
        } else {
            echo "<br>ERROR upload http-code result: ".$status;
            return false;
        }
    }

    private function getAccessToken() {
        $cmsk = explode(':', base64_decode($this->cmsK));
        $token = null;

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL,            $this->authUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST,           1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($ch, CURLOPT_POSTFIELDS,     json_encode(array(
            "username" => $cmsk[0],
            "password" => $cmsk[1],
            "rememberMe" => true
        ), JSON_UNESCAPED_SLASHES));
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
        $result = curl_exec($ch);
        $status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if($status === 200) {
            $token = json_decode($result);
        } else {
            $this->quite(FAILED_TO_GET_TOKEN);
        }

        return "Bearer ".$token->access_token;
    }

    private function quite($errorCode){
        switch($errorCode) {
            case INVALID_DIR_PATH: case FAILED_TO_GET_TOKEN: case UPLOAD_FAILED:
                header("HTTP/1.1 500 OK");
                echo "<br>ERROR: ".json_encode($errorCode);
                break;
            default:
                header("HTTP/1.1 200 OK");
                echo "<br>Success";
                break;
        }
        exit;
    }
}

$log = new LogUpload();
$log->zipAndUploadCSVFiles();
